# ListVMMachineTypesResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count_vm_available** | **int** |  | 
**cpu_models** | [**list[CpuModelCategory]**](CpuModelCategory.md) |  | 
**data_centers** | [**list[DataCenterCategory]**](DataCenterCategory.md) |  | 
**gpu_models** | [**list[GpuModelCategory]**](GpuModelCategory.md) |  | 
**host_configs** | [**list[HostConfigCategory]**](HostConfigCategory.md) |  | 
**max_gpu** | **int** |  | 
**max_memory_gib** | **int** |  | 
**max_vcpu** | **int** |  | 
**request** | [**ListVMMachineTypesRequest**](ListVMMachineTypesRequest.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


